import { ObjectId } from 'bson';
import { Environment } from '../bootstrapping/environment';
import { EveClient } from './eve-client';
export declare const FEED_SETUP_STATES: readonly ["NoFeed", "ItemSelection", "Mapping", "Done"];
export declare type FeedSetupState = typeof FEED_SETUP_STATES[number];
export declare const FEED_STATUSES: readonly ["Ok", "NoData", "UrlUnreachable", "BadMapping", "BadItem", "PossibleBadItem", "Timeout", "Unauthorized", "NoProducts", "IncorrectData", "ErrorWhileDownloading"];
export declare type FeedStatus = typeof FEED_STATUSES[number];
export declare const VALIDATION_FIELD_TYPES: string[];
export declare type ValidationFieldType = typeof VALIDATION_FIELD_TYPES[number];
export interface ApiInputFeed {
    feedUrl: string;
    decompress?: boolean;
    encoding?: string;
    item?: string;
    mapping?: {
        [key: string]: string;
    };
    auth?: string;
    js?: string;
    useCommaDelimiter?: true;
    anyDecimal?: true;
}
export interface ApiFeed extends ApiInputFeed {
    companyId: ObjectId;
    setupState: FeedSetupState;
    status: FeedStatus;
    feedSample?: string;
    elementNames?: string[];
    pathValues?: {
        path: string;
        values: string[];
    }[];
}
export interface ApiFeedValidationParams {
    type: ValidationFieldType;
    values: string[];
}
export interface ApiFeedValidationResult {
    value: string;
    parsedValue: string;
    status: 'success' | 'error';
}
export declare class FeedClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    private static getUrl;
    set(companyId: ObjectId, payload: ApiInputFeed): Promise<ApiFeed>;
    get(companyId: ObjectId, excludeSampleData?: boolean): Promise<ApiFeed>;
    validateFeed(field: ApiFeedValidationParams): Promise<ApiFeedValidationResult[]>;
}
