import { EveClient } from './eve-client';
import { ApiOrderStatus, Environment } from '..';
import { ObjectId } from 'bson';
import { MallType } from '..';
import { ApiFulfillmentStatus } from './fulfillments-client';
export interface ApiMallFulfillment {
    companyId: ObjectId;
    marketplaceOrderId: string;
    marketplace: MallType;
    trackingNumber: string;
    trackingUrl: string;
    status: ApiFulfillmentStatus;
}
export interface ApiMallFulfillmentResponse {
    fulfilled: boolean;
    correctOrderStatus?: ApiOrderStatus;
}
export declare class MallServiceClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    getDeliveryMethods(companyId: ObjectId): Promise<ApiMallDeliveryMethod[]>;
    fulfillOrder(companyId: ObjectId, fulfillment: ApiMallFulfillment): Promise<ApiMallFulfillmentResponse>;
    getCredentials(companyId: ObjectId, marketplace: MallType): Promise<ApiMallCredentials>;
    updateCredentials(companyId: ObjectId, marketplace: MallType, authorizationKey: string, active: boolean): Promise<ApiMallDeliveryMethod[]>;
    deleteCredentials(companyId: ObjectId, marketplace: MallType): Promise<ApiMallCredentials>;
    getStatuses(companyId: ObjectId): Promise<{
        marketplace: MallType;
        status: 'online' | 'offline';
    }[]>;
}
export interface ApiMallDeliveryMethod {
    code: string;
    title: string;
    marketplace: MallType;
    isPickupPoint: boolean;
}
export interface ApiMallCredentials {
    companyId: ObjectId;
    authorizationKey: string;
    webhookId: string;
    marketplace: MallType;
    active: boolean;
}
