import { ObjectId } from 'bson';
import { ApiVariant, Environment } from '..';
import { EveClient } from './eve-client';
import { MarketplaceName } from '..';
export declare type ListingStatusKind = 'ok' | 'error';
export declare type ProductStatusKind = 'ok' | 'paused' | 'notFound' | 'error' | 'missingBarcode';
export interface ApiListingError {
    code: string;
    message: string;
}
export interface ApiListingStatus {
    companyId: ObjectId;
    marketplace: MarketplaceName;
    sku: string;
    listingStatus: ListingStatusKind;
    listingErrors: ApiListingError[];
}
export interface ApiProductStatuses {
    companyId: ObjectId;
    marketplace: MarketplaceName;
    sku: string;
    hasAsin: boolean;
    hasStock: boolean;
    hasValidBarcode: boolean;
    isBuyBoxWinner: boolean;
    listingStatus: ListingStatusKind;
    listingErrors: ApiListingError[];
    status: ProductStatusKind;
    forbidListing?: boolean;
}
export interface ApiProductStats {
    companyId: ObjectId;
    marketplaces: MarketplaceName[];
    ok: number;
    paused: number;
    notFound: number;
    error: number;
    missingBarcode: number;
    buyBox?: ApiBuyBoxStats;
}
export interface ApiBuyBoxStats {
    isInBuyBoxCount: number;
    notInBuyBoxCount: number;
}
export declare class ProductStatusesClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    getListingStatus(companyId: ObjectId, sku: string): Promise<ApiListingStatus[]>;
    getForbidListings(companyId: ObjectId, sku: string): Promise<any>;
    blockProducts(companyId: ObjectId, variants: ApiVariant[]): Promise<{
        totalCount: number;
        foundCount: number;
        notFoundSkus: string[];
    }>;
    updateForbidListings(companyId: ObjectId, productVariants: ApiVariant[]): Promise<{
        totalCount: number;
        foundCount: number;
        notFoundSkus: string[];
    }>;
    getProductStatuses(companyId: ObjectId, marketplaces: MarketplaceName[], sku: string): Promise<ApiProductStatuses[]>;
    getManyProductStatuses(companyId: ObjectId, marketplace: MarketplaceName[], sku: string[]): Promise<ApiProductStatuses[]>;
    getProductStats(companyId: ObjectId, marketplaces: MarketplaceName[], hasStockFilter: boolean): Promise<ApiProductStats>;
}
