export declare class QueueProcessor<T> {
    private processFn;
    private queue;
    private runningJobs;
    private concurrent;
    private waiting;
    private handleResult;
    private handleError;
    constructor(processFn: (queueItem: T) => any, options?: {
        handleResult?: (r: any, i: T) => void;
        handleError?: (e: any, i: T) => void;
        concurrency?: number;
    });
    /**
     * Add item to a FIFO queue - will be processed when available
     */
    addToQueue(item: T): void;
    /**
     * Add an item to be processed as soon as possible skipping ahead of queue.
     * This action will not exceed the concurrency limit.
     */
    addRunning(item: T): Promise<void>;
    /**
     * Add an item or a function to be processed as soon as possible skipping ahead of queue.
     * This action will not exceed the concurrency limit.
     * This function will return a result and may raise exceptions.
     * This function ignores handleResult and handleError in options.
     */
    process(input: (() => Promise<any>) | T): Promise<any>;
    /**
     * Set the amount of concurrent jobs.
     * This action will automatically run new jobs if possible.
     */
    set concurrency(concurrency: number);
    /**
     * Get the amount of concurrent jobs.
     */
    get concurrency(): number;
    /**
     * Awaitable call to make sure queue has been depleted and all running jobs have finished
     */
    finish(): Promise<void>;
    /**
     * Number of currently running jobs
     */
    get running(): number;
    /**
     * Number of item in the queue
     */
    get enqueued(): number;
    private reserveImmediateSlot;
    private get currentPromises();
    private get canRunProcess();
    private runProcess;
    private runAvailable;
}
